% Computes the likelihood for the full ML method with site effects using
% a univariate Kalman filter.
% Inputs to the function:
%       ymean : vector of annual average population observations
%       a,c,s2,so2,syear2 : parameter values
%       a1, P1 : Prior mean and variance matrix of the first state
%       d : number of replicate observations
%       S2 : sum of sample variances
% Output returned:
%       nLL : negative log likelihood at input parameters
% Written by Jonas Knape (jonas.knape@slu.se).
function nLL = fullNLL(ymean,a,c,s2,so2,syear2,a1,P1,d,S2)
    T = length(ymean);
    LLmean = kalman(ymean,so2/d + syear2, c,a,s2,a1,P1);
    nLL = .5*((d-1)*S2/so2+T*log(d)+T*(d-1)*log(2*pi*so2))-LLmean;
end
