% Kalman filter for a state space model
% y(t) = x(t) + eps(t), eps(t)~N(0,H), t=1,...,n
% x(t+1) = W+T*x(t)+eta(t), eta~N(0,Q)
% x(1)~N(a1,P1)
% Inputs to the function:
%       y : data
%       H, T, W, Q: model parameters
%       a1, P1 : Prior mean and variance matrix of the first state
% Output returned:
%       LL : log likelihood at input parameters
%
% Written by Jonas Knape (jonas.knape@slu.se).

function [LL] = kalman(y,H,T,W,Q,a1,P1)
n = length(y);
%Kalman filter recursions
a = a1;
P = P1;
LL=0;
for i = 1:n
    v=y(i)-a;
    F=P+H;
    K=T*P/F;
    if i < n
        a=W+T*a+K*v;
        P=T*P*(T-K) + Q;
    end
    LL = LL -1/2*log(2*pi) - log(F)/2 - v^2/F/2;
end
